from typing import List

from statham.schema.constants import Maybe
from statham.schema.elements import Array, Object, String
from statham.schema.property import Property


class Model(Object):

    list_of_strings: Maybe[List[str]] = Property(Array(String()))



from statham.schema.constants import Maybe
from statham.schema.elements import Object, String
from statham.schema.property import Property


class Category(Object):

    required_name: str = Property(String(), required=True)


class NestedRemote(Object):

    name: Maybe[str] = Property(String())


class Remote(Object):

    name: Maybe[str] = Property(String())

    nested: Maybe[NestedRemote] = Property(NestedRemote)


class Model(Object):

    filesystem_remote_ref_flat: Maybe[Category] = Property(Category)

    filesystem_remote_ref_directory: Maybe[Remote] = Property(Remote)



from typing import List

from statham.schema.constants import Maybe
from statham.schema.elements import Array, Object, String
from statham.schema.property import Property


class Category(Object):

    required_name: str = Property(String(), required=True)


class Child(Object):

    name: Maybe[str] = Property(String())

    category: Maybe[Category] = Property(Category)


class Model(Object):

    children: Maybe[List[Child]] = Property(Array(Child))

    category: Maybe[Category] = Property(Category)



from statham.schema.constants import Maybe
from statham.schema.elements import Integer, Object
from statham.schema.property import Property


class MyTestJSONSchema(Object):

    id: Maybe[int] = Property(Integer())
